pynrc.simul.apt.DMS\_input
==========================

.. currentmodule:: pynrc.simul.apt

.. autoclass:: DMS_input
   :members:
   :inherited-members:
   :show-inheritance:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DMS_input.__init__
      ~DMS_input.gen_all_obs_params
      ~DMS_input.gen_obs_params
      ~DMS_input.gen_pitch_array
      ~DMS_input.make_jwst_point
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DMS_input.obs_date
      ~DMS_input.obs_time
      ~DMS_input.pa_v3
   
   